@@ -12,10 +12,10 @@
 #
 ##############################################################################
 """
-$Id: test_logout.py 98048 2009-03-13 20:14:26Z nadako $
+$Id: test_logout.py 111660 2010-04-30 17:27:53Z hannosch $
 """
+import doctest
 import unittest
-from zope.testing import doctest
 
 from zope.component import provideAdapter, adapts
 from zope.interface import implements
