@@ -13,10 +13,10 @@
 ##############################################################################
 """Test for principal lookup related functionality
 
-$Id: test_principal.py 97937 2009-03-11 22:44:45Z nadako $
+$Id: test_principal.py 111660 2010-04-30 17:27:53Z hannosch $
 """
+import doctest
 import unittest
-from zope.testing import doctest
 
 
 def test_suite():
